spec.settings

Organizes and validates your settings with clojure.spec and spec-tools.

Organizes and validates your settings with clojure.spec and spec-tools.
raw docstring

all-settingsclj

(all-settings)
(all-settings settings-config)
(all-settings settings-config filter-prefix)

SampleAPI settings. If given a filter prefix, only return keys from environment/props matching that prefix

SampleAPI settings. If given a filter prefix, only return keys from environment/props matching that prefix
sourceraw docstring

defaultsclj

(defaults & [settings-config])

SampleAPI settings defaults

SampleAPI settings defaults
sourceraw docstring

envclj

(env & [filter-prefix])

SampleAPI settings from the environment

SampleAPI settings from the environment
sourceraw docstring

propsclj

(props & [filter-prefix])

SampleAPI settings from properties

SampleAPI settings from properties
sourceraw docstring

settings-specclj

(settings-spec spec-name settings-config)
(settings-spec spec-name settings-config lenient?)
source

validate-settings!clj

(validate-settings! settings-spec)
(validate-settings! settings-spec all-settings)

Validates all-settings meet the settings-spec. Exits the process with explanation on failure.

Validates all-settings meet the settings-spec. Exits the process with explanation on failure.
sourceraw docstring

validate-settings-fnclj

(validate-settings-fn settings-spec all-settings)

Validates all-settings meet the settings-spec.

Validates all-settings meet the settings-spec.
sourceraw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries